"""

  Copyright 2005 Mikko Ohtamaa

  See class comments for more details

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as described
  in licence.txt

"""
# Zope imports
from OFS.SimpleItem import SimpleItem
from OFS.PropertyManager import PropertyManager
from Products.PageTemplates.PageTemplateFile import PageTemplateFile
from AccessControl import ClassSecurityInfo
from Globals import InitializeClass

# Plone imports
from Products.CMFCore.utils import UniqueObject
from Products.CMFCore.ActionProviderBase import ActionProviderBase
from Products.CMFPlone.PloneBaseTool import PloneBaseTool
from Products.Archetypes.Referenceable import Referenceable

# Product imports
from Products.Usability.Permissions import *

class UsabilityTool(PloneBaseTool, UniqueObject, SimpleItem, Referenceable, PropertyManager):
    """ Back office tool for usability issue management
    
    - Manage usability issue id counter
    
    """
    
    __implements__ = (PloneBaseTool.__implements__, SimpleItem.__implements__, )

    meta_type = "Usability Issues Administration Tool"
    title = "Usability Issues Administration Tool"
    id = 'portal_usability'
    
    # do not appear in ZMI tree view
    isPrincipiaFolderish = False
    
    # Security object for this class
    security = ClassSecurityInfo()

    manage_options = (
        (
                {'label': 'Overview', 'action': 'manage_overview',},
                {'label': 'Issues', 'action': 'manage_issues'}
        ) + PropertyManager.manage_options + SimpleItem.manage_options
    )
        
    _properties = PropertyManager._properties + (
        {'id':'issueIdCounter', 'type':'int', 'mode':'w'},
    )
    
    # last reserved global issue id
    issueIdCounter = 0
    
    
    # overview page (must be present on all items)
    security.declareProtected(CMFCorePermissions.ManagePortal, 'manage_overview')
    manage_overview = PageTemplateFile('www/portal_usability_manage_overview', globals())
    manage_overview.__name__ = 'manage_overview'
    manage_overview._need__name__ = 0    
        
    # issue management page
    security.declareProtected(CMFCorePermissions.ManagePortal, 'manage_issues')
    manage_issues = PageTemplateFile('www/portal_usability_manage_issues', globals())
    manage_issues.__name__ = 'manage_issues'
    manage_issues._need__name__ = 0
    
    security.declareProtected('Manage properties', 'index_html')
    index_html = PageTemplateFile('zpt/index_html', globals())
    
    manage_main = manage_overview

    security.declareProtected(CMFCorePermissions.ManagePortal, 'manage_setIssueIdCounter')
    def manage_setIssueIdCounter(self, REQUEST=None):
        """ Resets issue id counter
        
        Because Archetype ids must be unique and by resetting the counter 
        we can have same ids, the results can be devastating. Be careful with this.
        """
        self.issueIdCounter = int(REQUEST.form["issueIdCounter"])
        msg = "Set issue id counter to " + str(self.issueIdCounter)    
        return self.manage_issues(self, REQUEST, manage_tabs_message=msg)
                
    security.declarePublic('getRunningIssueId')
    def getRunningIssueId(self):
        """ Returns last used issue id """
        return self.issueIdCounter
        
    security.declareProtected(EDIT_USABILITY_ITEMS_PERMISSION, 'nextIssueId')
    def nextIssueId(self):
        """ Returns a issue id for a new object """
        self.issueIdCounter += 1
        return self.issueIdCounter

InitializeClass(UsabilityTool)
